==> ark-17.08.3-1-src.tar.xz: ark-17.08.3/plugins/libzipplugin/kerfuffle_libzip.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the zip archive format",
        "Description[ca@valencia]": "Implementació completa del format d'arxiu ZIP",
        "Description[ca]": "Implementació completa del format d'arxiu ZIP",
        "Description[cs]": "Plná podpora archivačního formátu zip",
        "Description[de]": "Vollständige Unterstützung für Zip-Archivformate",
        "Description[el]": "Πλήρης υποστήριξη για την αρχειοθήκη μορφής zip",
        "Description[es]": "Uso total del formato de archivo comprimido zip",
        "Description[eu]": "Zip artxibo formatuarentzako euskarri osoa",
        "Description[fr]": "Prise en charge complète du format d'archive ZIP",
        "Description[it]": "Supporto completo per il formato di archivi ZIP",
        "Description[nl]": "Volledige ondersteuning voor het zip-archiefformaat",
        "Description[nn]": "Full støtte for arkivformatet ZIP",
        "Description[pl]": "Pełna obsługa dla formatów archiwów zip",
        "Description[pt]": "Suporte total para o formato de pacotes ZIP",
        "Description[sk]": "Plná podpora pre archívny formát zip",
        "Description[sl]": "Polna podpora za arhive vrste zip",
        "Description[sr@ijekavian]": "Пуна подршка за архивски формат ЗИП",
        "Description[sr@ijekavianlatin]": "Puna podrška za arhivski format ZIP",
        "Description[sr@latin]": "Puna podrška za arhivski format ZIP",
        "Description[sr]": "Пуна подршка за архивски формат ЗИП",
        "Description[sv]": "Fullt stöd för arkivformatet zip",
        "Description[tr]": "Zip arşivi biçimi için tam destek",
        "Description[uk]": "Повноцінна підтримка архівів у форматі zip",
        "Description[x-test]": "xxFull support for the zip archive formatxx",
        "Description[zh_CN]": "完全支持 zip 归档格式",
        "Description[zh_TW]": "對 zip 壓縮檔格式的完整支援",
        "Id": "kerfuffle_libzip",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Libzip plugin",
        "Name[ca@valencia]": "Connector del Libzip",
        "Name[ca]": "Connector del Libzip",
        "Name[cs]": "Modul pro libzip",
        "Name[de]": "Libzip-Modul",
        "Name[el]": "Πρόσθετο Libzip",
        "Name[es]": "Complemento Libzip",
        "Name[eu]": "Libzip plugina",
        "Name[fr]": "Module externe « libzip »",
        "Name[it]": "Estensione Libzip",
        "Name[nl]": "Libzip-plug-in",
        "Name[nn]": "Libzip-tillegg",
        "Name[pl]": "Wtyczka libzip",
        "Name[pt]": "'Plugin' da Libzip",
        "Name[ru]": "Модуль Libzip",
        "Name[sk]": "Plugin Libzip",
        "Name[sl]": "Vstavek Libzip",
        "Name[sr@ijekavian]": "Прикључак за Либзип",
        "Name[sr@ijekavianlatin]": "Priključak za libzip",
        "Name[sr@latin]": "Priključak za libzip",
        "Name[sr]": "Прикључак за Либзип",
        "Name[sv]": "Libzip-insticksprogram",
        "Name[tr]": "Libzip eklentisi",
        "Name[uk]": "Додаток libzip",
        "Name[x-test]": "xxLibzip pluginxx",
        "Name[zh_CN]": "Libzip 插件",
        "Name[zh_TW]": "Libzip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 200,
    "application/zip": {
        "Encryption": true,
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256",
            "AES192",
            "AES128"
        ],
        "SupportsTesting": true,
        "SupportsWriteComment": true
    }
}

==> ark-17.12.3-1-src.tar.xz: ark-17.12.3/plugins/libzipplugin/kerfuffle_libzip.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the zip archive format",
        "Description[ca@valencia]": "Implementació completa del format d'arxiu ZIP",
        "Description[ca]": "Implementació completa del format d'arxiu ZIP",
        "Description[cs]": "Plná podpora archivačního formátu zip",
        "Description[da]": "Fuld understøttelse af zip-arkivformater",
        "Description[de]": "Vollständige Unterstützung für Zip-Archivformate",
        "Description[el]": "Πλήρης υποστήριξη για την αρχειοθήκη μορφής zip",
        "Description[es]": "Uso total del formato de archivo comprimido zip",
        "Description[eu]": "Zip artxibo formatuarentzako euskarri osoa",
        "Description[fi]": "Täysi Zip-tiedostomuodon tuki",
        "Description[fr]": "Prise en charge complète du format d'archive ZIP",
        "Description[gl]": "Compatibilidade total co formato de arquivo zip.",
        "Description[it]": "Supporto completo per il formato di archivi ZIP",
        "Description[ko]": "zip 압축 형식 지원",
        "Description[nl]": "Volledige ondersteuning voor het zip-archiefformaat",
        "Description[nn]": "Full støtte for arkivformatet ZIP",
        "Description[pl]": "Pełna obsługa dla archiwów zip",
        "Description[pt]": "Suporte total para o formato de pacotes ZIP",
        "Description[ru]": "Полная поддержка архивов ZIP",
        "Description[sk]": "Plná podpora pre archívny formát zip",
        "Description[sl]": "Polna podpora za arhive vrste zip",
        "Description[sr@ijekavian]": "Пуна подршка за архивски формат ЗИП",
        "Description[sr@ijekavianlatin]": "Puna podrška za arhivski format ZIP",
        "Description[sr@latin]": "Puna podrška za arhivski format ZIP",
        "Description[sr]": "Пуна подршка за архивски формат ЗИП",
        "Description[sv]": "Fullt stöd för arkivformatet zip",
        "Description[tr]": "Zip arşivi biçimi için tam destek",
        "Description[uk]": "Повноцінна підтримка архівів у форматі zip",
        "Description[x-test]": "xxFull support for the zip archive formatxx",
        "Description[zh_CN]": "完全支持 zip 归档格式",
        "Description[zh_TW]": "對 zip 壓縮檔格式的完整支援",
        "Id": "kerfuffle_libzip",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Libzip plugin",
        "Name[ca@valencia]": "Connector del Libzip",
        "Name[ca]": "Connector del Libzip",
        "Name[cs]": "Modul pro libzip",
        "Name[da]": "Libzip-plugin",
        "Name[de]": "Libzip-Modul",
        "Name[el]": "Πρόσθετο Libzip",
        "Name[es]": "Complemento Libzip",
        "Name[eu]": "Libzip plugina",
        "Name[fi]": "Libzip-liitännäinen",
        "Name[fr]": "Module externe « libzip »",
        "Name[gl]": "Complemento de libzip",
        "Name[it]": "Estensione Libzip",
        "Name[ko]": "Libzip 플러그인",
        "Name[nl]": "Libzip-plug-in",
        "Name[nn]": "Libzip-tillegg",
        "Name[pl]": "Wtyczka libzip",
        "Name[pt]": "'Plugin' da Libzip",
        "Name[ru]": "Модуль Libzip",
        "Name[sk]": "Plugin Libzip",
        "Name[sl]": "Vstavek Libzip",
        "Name[sr@ijekavian]": "Прикључак за Либзип",
        "Name[sr@ijekavianlatin]": "Priključak za libzip",
        "Name[sr@latin]": "Priključak za libzip",
        "Name[sr]": "Прикључак за Либзип",
        "Name[sv]": "Libzip-insticksprogram",
        "Name[tr]": "Libzip eklentisi",
        "Name[uk]": "Додаток libzip",
        "Name[x-test]": "xxLibzip pluginxx",
        "Name[zh_CN]": "Libzip 插件",
        "Name[zh_TW]": "Libzip 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Priority": 200,
    "application/zip": {
        "CompressionLevelDefault": 6,
        "CompressionLevelMax": 9,
        "CompressionLevelMin": 1,
        "CompressionMethodDefault": "Default",
        "CompressionMethods": {
            "BZip2": "BZip2",
            "Default": "Default",
            "Deflate": "Deflate",
            "Store": "Store"
        },
        "Encryption": true,
        "EncryptionMethodDefault": "AES256",
        "EncryptionMethods": [
            "AES256",
            "AES192",
            "AES128"
        ],
        "SupportsTesting": true,
        "SupportsWriteComment": true
    }
}
